@@ -9,7 +9,7 @@
 #
 package MooseX::TrackDirty::Attributes::Trait::Attribute::Native::Trait;
 {
-  $MooseX::TrackDirty::Attributes::Trait::Attribute::Native::Trait::VERSION = '2.001';
+  $MooseX::TrackDirty::Attributes::Trait::Attribute::Native::Trait::VERSION = '2.002';
 }
 
 # ABSTRACT: Compatibility trait between the track-dirty and native traits
@@ -51,12 +51,13 @@ around _native_accessor_class_for => sub {
 
 !!42;
 
+__END__
 
 =pod
 
 =encoding utf-8
 
-=for :stopwords Chris Weyl
+=for :stopwords Chris Weyl Gianni Ceccarelli attribute's
 
 =head1 NAME
 
@@ -64,7 +65,7 @@ MooseX::TrackDirty::Attributes::Trait::Attribute::Native::Trait - Compatibility
 
 =head1 VERSION
 
-This document describes version 2.001 of MooseX::TrackDirty::Attributes::Trait::Attribute::Native::Trait - released July 19, 2012 as part of MooseX-TrackDirty-Attributes.
+This document describes version 2.002 of MooseX::TrackDirty::Attributes::Trait::Attribute::Native::Trait - released November 24, 2012 as part of MooseX-TrackDirty-Attributes.
 
 =head1 SEE ALSO
 
@@ -96,6 +97,10 @@ feature.
 
 Chris Weyl <cweyl@alumni.drew.edu>
 
+=head1 CONTRIBUTOR
+
+Gianni Ceccarelli <gianni.ceccarelli@net-a-porter.com>
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2011 by Chris Weyl.
@@ -105,6 +110,3 @@ This is free software, licensed under:
   The GNU Lesser General Public License, Version 2.1, February 1999
 
 =cut
-
-
-__END__
