@@ -9,7 +9,7 @@
 #
 package MooseX::TrackDirty::Attributes::Trait::Method::Accessor;
 {
-  $MooseX::TrackDirty::Attributes::Trait::Method::Accessor::VERSION = '2.001';
+  $MooseX::TrackDirty::Attributes::Trait::Method::Accessor::VERSION = '2.002';
 }
 
 # ABSTRACT: Track dirtied attributes
@@ -124,13 +124,13 @@ sub _generate_is_dirty_method_inline {
 
 !!42;
 
-
+__END__
 
 =pod
 
 =encoding utf-8
 
-=for :stopwords Chris Weyl
+=for :stopwords Chris Weyl Gianni Ceccarelli attribute's
 
 =head1 NAME
 
@@ -138,7 +138,7 @@ MooseX::TrackDirty::Attributes::Trait::Method::Accessor - Track dirtied attribut
 
 =head1 VERSION
 
-This document describes version 2.001 of MooseX::TrackDirty::Attributes::Trait::Method::Accessor - released July 19, 2012 as part of MooseX-TrackDirty-Attributes.
+This document describes version 2.002 of MooseX::TrackDirty::Attributes::Trait::Method::Accessor - released November 24, 2012 as part of MooseX-TrackDirty-Attributes.
 
 =head1 DESCRIPTION
 
@@ -179,6 +179,10 @@ feature.
 
 Chris Weyl <cweyl@alumni.drew.edu>
 
+=head1 CONTRIBUTOR
+
+Gianni Ceccarelli <gianni.ceccarelli@net-a-porter.com>
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2011 by Chris Weyl.
@@ -188,7 +192,3 @@ This is free software, licensed under:
   The GNU Lesser General Public License, Version 2.1, February 1999
 
 =cut
-
-
-__END__
-
