@@ -9,7 +9,7 @@
 #
 package MooseX::TrackDirty::Attributes::Trait::Role::Application::ToInstance;
 {
-  $MooseX::TrackDirty::Attributes::Trait::Role::Application::ToInstance::VERSION = '2.001';
+  $MooseX::TrackDirty::Attributes::Trait::Role::Application::ToInstance::VERSION = '2.002';
 }
 
 # ABSTRACT: Application to instance helper trait
@@ -53,13 +53,13 @@ after apply => sub {
 
 !!42;
 
-
+__END__
 
 =pod
 
 =encoding utf-8
 
-=for :stopwords Chris Weyl
+=for :stopwords Chris Weyl Gianni Ceccarelli attribute's
 
 =head1 NAME
 
@@ -67,7 +67,7 @@ MooseX::TrackDirty::Attributes::Trait::Role::Application::ToInstance - Applicati
 
 =head1 VERSION
 
-This document describes version 2.001 of MooseX::TrackDirty::Attributes::Trait::Role::Application::ToInstance - released July 19, 2012 as part of MooseX-TrackDirty-Attributes.
+This document describes version 2.002 of MooseX::TrackDirty::Attributes::Trait::Role::Application::ToInstance - released November 24, 2012 as part of MooseX-TrackDirty-Attributes.
 
 =head1 SEE ALSO
 
@@ -99,6 +99,10 @@ feature.
 
 Chris Weyl <cweyl@alumni.drew.edu>
 
+=head1 CONTRIBUTOR
+
+Gianni Ceccarelli <gianni.ceccarelli@net-a-porter.com>
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2011 by Chris Weyl.
@@ -108,8 +112,3 @@ This is free software, licensed under:
   The GNU Lesser General Public License, Version 2.1, February 1999
 
 =cut
-
-
-__END__
-
-
