@@ -9,7 +9,7 @@
 #
 package MooseX::TrackDirty::Attributes::Util;
 {
-  $MooseX::TrackDirty::Attributes::Util::VERSION = '2.001';
+  $MooseX::TrackDirty::Attributes::Util::VERSION = '2.002';
 }
 
 # ABSTRACT: Laziness -- alias functions
@@ -37,13 +37,13 @@ sub AccessorNativeTrait()   { trait_for 'Method::Accessor::Native'           }
 
 !!42;
 
-
+__END__
 
 =pod
 
 =encoding utf-8
 
-=for :stopwords Chris Weyl
+=for :stopwords Chris Weyl Gianni Ceccarelli attribute's
 
 =head1 NAME
 
@@ -51,7 +51,7 @@ MooseX::TrackDirty::Attributes::Util - Laziness -- alias functions
 
 =head1 VERSION
 
-This document describes version 2.001 of MooseX::TrackDirty::Attributes::Util - released July 19, 2012 as part of MooseX-TrackDirty-Attributes.
+This document describes version 2.002 of MooseX::TrackDirty::Attributes::Util - released November 24, 2012 as part of MooseX-TrackDirty-Attributes.
 
 =for Pod::Coverage trait_for application Composite ^To.*$ TrackDirtyNativeTrait AccessorNativeTrait
 
@@ -85,6 +85,10 @@ feature.
 
 Chris Weyl <cweyl@alumni.drew.edu>
 
+=head1 CONTRIBUTOR
+
+Gianni Ceccarelli <gianni.ceccarelli@net-a-porter.com>
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2011 by Chris Weyl.
@@ -94,7 +98,3 @@ This is free software, licensed under:
   The GNU Lesser General Public License, Version 2.1, February 1999
 
 =cut
-
-
-__END__
-
